Learn R Programming

dendextend (version 0.17.5)

assign_values_to_branches_edgePar: Assign values to edgePar of dendrogram's branches

Description

Go through the dendrogram branches and updates the values inside its edgePar If the value has Inf then the value in edgePar will not be changed.

Usage

assign_values_to_branches_edgePar(object, value, edgePar, skip_leaves = FALSE,
  warn = dendextend_options("warn"), ...)

Arguments

object
a dendrogram object
value
a new value scalar for the edgePar attribute.
edgePar
the value inside edgePar to adjust.
skip_leaves
logical (FALSE) - should the leaves be skipped/ignored?
warn
logical (default from dendextend_options("warn") is FALSE). Set if warning are to be issued, it is safer to keep this at TRUE, but for keeping the noise down, the default is FALSE.
...
not used

Value

  • A dendrogram, after adjusting the edgePar attribute in all of its branches,

See Also

get_branches_attr

Examples

Run this code
dend <- USArrests[1:5,] %>% dist %>% hclust %>% as.dendrogram
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "lwd")
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "col")
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "lty")
plot(dend)

Run the code above in your browser using DataLab