Learn R Programming

dendextend (version 0.16.1)

assign_values_to_branches_edgePar: Assign values to edgePar of dendrogram's branches

Description

Go through the dendrogram branches and updates the values inside its edgePar If the value has NA then the value in edgePar will not be changed. (it could have also been something like NULL or Inf, but for now it is only NA)

Usage

assign_values_to_branches_edgePar(object, value, edgePar, skip_leaves = FALSE,
  warn = TRUE, ...)

Arguments

object
a dendrogram object
value
a new value scalar for the edgePar attribute.
edgePar
the value inside edgePar to adjust.
skip_leaves
logical (FALSE) - should the leaves be skipped/ignored?
warn
logical (TRUE). Should warning be issued? Generally, it is safer to keep this at TRUe. But for specific uses it might be more user-friendly to turn it off (for example, in the tanglegram function)
...
not used

Value

  • A dendrogram, after adjusting the edgePar attribute in all of its branches,

See Also

get_branches_attr

Examples

Run this code
dend <- USArrests[1:5,] %>% dist %>% hclust %>% as.dendrogram
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "lwd")
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "col")
plot(dend)
dend <- assign_values_to_branches_edgePar(object=dend, value = 2, edgePar = "lty")
plot(dend)

Run the code above in your browser using DataLab