Vectorized function for checking if numbers are natural or
not. Helps in checking if a vector is of type "order".
Usage
is.natural.number(x, tol = .Machine$double.eps^0.5, ...)
Arguments
x
a vector of numbers
tol
tolerence to floating point issues.
...
(not currently in use)
Value
logical - is the entered number natural or not.
source
This function was written by marcog, as an answer to my
question here:
http://stackoverflow.com/questions/4562257/what-is-the-fastest-way-to-check-if-a-number-is-a-positive-natural-number-in-r